@@ -86,6 +86,7 @@ logger = logging.getLogger(__name__)
 
 def farewell(signum, frame):
     logger.debug('farewell')
+    requests.post(my_bot, 'farewell')
     CoreAgent.sock.close()
     return
 
@@ -740,5 +741,4 @@ if __name__ == '__main__':
     tcp_port = 6591
 
     signal.signal(signal.SIGTERM, farewell)
-    agent = CoreAgent()
-    agent.run(host=tcp_host, port=tcp_port)
+    CoreAgent.run(host=tcp_host, port=tcp_port)
